//
//  RedLaserSDK.m
//  ScanditBarcodeScanner
//
//  Created by Moritz Hartmeier on 20/08/15.
//  Copyright (c) 2015 Scandit AG. All rights reserved.
//

#import "RedLaserSDK.h"

#import <AVFoundation/AVFoundation.h>


void RL_RequestVideoAuthorization(RL_RequestVideoAuthorizationCompletionHandler handler) {
    if (NSFoundationVersionNumber > NSFoundationVersionNumber_iOS_7_1) {
        AVAuthorizationStatus authStatus = [AVCaptureDevice authorizationStatusForMediaType:AVMediaTypeVideo];
        if (authStatus == AVAuthorizationStatusAuthorized) {
            handler(RL_VideoAuthorizationStatusAuthorized);
        } else if (authStatus == AVAuthorizationStatusDenied) {
            handler(RL_VideoAuthorizationStatusDenied);
        } else if (authStatus == AVAuthorizationStatusRestricted) {
            handler(RL_VideoAuthorizationStatusRestricted);
        } else {
            handler(RL_VideoAuthorizationStatusNotDetermined);
        }
    } else {
        handler(RL_VideoAuthorizationStatusAuthorized);
    }
}

/*******************************************************************************
	FindBarcodesInUIImage
	
	Searches the given image for barcodes, and returns information on all barcodes
	that it finds. This performs an exhaustive search, which can take several
	seconds to perform. This method searches for all barcode types. The intent
	of this method is to allow for barcode searching in photos from the photo library.
 */
NSSet *FindBarcodesInUIImage(UIImage *inputImage) {
    return [NSSet set];
}




/*******************************************************************************
	RL_GetRedLaserSDKVersion()
	
	This function returns the version of the RedLaser SDK, as a NSString.
	The primary purpose of this function is checking which SDK version you're
	linking against, to compare that version against the most recent version
	on redlaser.com.
 */
NSString *RL_GetRedLaserSDKVersion() {
    return @"3.4";
}

/*******************************************************************************
	RL_CheckReadyStatus()
	
	This function returns information about whether the SDK can be used. It
	doesn't give dynamic state information about what the SDK is currently doing.
	
	Generally, positive values mean you can scan, negative values mean you
	can't. The returned value *can* change from one call to the next.
	
	If this function returns a negative value, it's usually best to design your
	app so that it won't attempt to scan at all. If this function returns
	MissingOSLibraries this is especially important, as the SDK will probably
	crash if used. See the documentation.
 */
RedLaserStatus RL_CheckReadyStatus() {
    return RLState_LicensedModeReady;
}


@implementation RedLaserSDK

@end
